"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.identity = exports.noop = exports.getOr = exports.memoize = void 0;

var memoize = function memoize(fn) {
  var cache = {};
  return function () {
    var cached = arguments.length <= 0 ? undefined : arguments[0];

    if (cached in cache) {
      return cache[cached];
    } else {
      var result = fn(cached);
      cache[cached] = result;
      return result;
    }
  };
};

exports.memoize = memoize;

var getOr = function getOr(path, object) {
  var defaultValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

  var _path = Array.isArray(path) ? path : path.split('.').filter(function (i) {
    return i.length;
  });

  if (!_path.length) {
    return object === undefined ? defaultValue : object;
  }

  return getOr(object[_path.shift()], _path, defaultValue);
};

exports.getOr = getOr;

var noop = function noop() {
  return undefined;
};

exports.noop = noop;

var identity = function identity(self) {
  return self;
};

exports.identity = identity;